@@ -51,12 +51,14 @@ def double_slider(node, st_kwargs, col):
                 key=f'{node}_max_val',
                 **st_kwargs,
             )
-            st.number_input('step', value=5, key=f'{node}_step', **st_kwargs)
+            st.number_input(
+                'step', min_value=1, value=5, key=f'{node}_step', **st_kwargs
+            )
             st.write(
                 pd.DataFrame(
                     np.arange(
                         start=int(st.session_state[f'{node}_min_val']),
-                        stop=int(st.session_state[f'{node}_max_val']),
+                        stop=int(st.session_state[f'{node}_max_val'] + 1),
                         step=int(st.session_state[f'{node}_step']),
                     )
                 ).transpose()
@@ -72,10 +74,28 @@ def vector_factory(dag, nodes, funcs, col):
 
 def update_vec_nodes(dag, nodes, funcs, col):
     with col:
-        st.write(dict(st.session_state))
+        for node in [node for node in nodes if node not in dag.roots]:
+            kwargs = dict()
+            for arg in list(funcs[node].sig.names):
+                if arg in dag.roots:
+                    kwargs[arg] = np.arange(
+                        start=int(st.session_state[f'{arg}_min_val']),
+                        stop=int(st.session_state[f'{arg}_max_val'] + 1),
+                        step=int(st.session_state[f'{arg}_step']),
+                    )
+                else:
+                    kwargs[arg] = st.session_state[arg]
+            if len(set(map(len, kwargs.values()))) == 1:
+                val = funcs[node].func(**kwargs)
+                st.session_state[node] = val
+                st.write(f'{node}: ')
+                # st.line_chart(st.session_state[node])
+                st.write(pd.DataFrame(st.session_state[node]).transpose())
+            else:
+                break
 
 
-# ------------------------------------ BINARY CLASSIFICATION ------------------------------------
+# ------------------------------------ STATIC NODES ------------------------------------
 
 
 def update_static_nodes(dag, nodes, funcs, col):
@@ -106,7 +126,7 @@ def update_static_nodes(dag, nodes, funcs, col):
                     for key in val.keys():
                         st.write(f"{key}: {st.session_state[f'{node}_{key}']}")
             else:
-                st.session_state[node] = funcs[node].func(**kwargs)
+                st.session_state[node] = val
                 st.write(f'{node}: {st.session_state[node]}')
 
 
@@ -134,13 +154,7 @@ def static_factory(dag, nodes, funcs, values, arg_types, ranges, col):
                 widget(node, **st_kwargs)
 
 
-# ------------------------------------ STANDARD UTILS ------------------------------------
-
-
-def get_from_configs(configs):
-    arg_types = configs['arg_types']
-    ranges = None if 'ranges' not in configs else configs['ranges']
-    return arg_types, ranges
+# ------------------------------------ INTERMEDIATE NODES ------------------------------------
 
 
 def display_factory(dag, nodes, funcs, values, arg_types, ranges, col):
@@ -179,6 +193,9 @@ def update_nodes(dag, node_ch, funcs):
         st.session_state[node] = funcs[node].func(*args)
 
 
+# ------------------------------------ STANDARD UTILS ------------------------------------
+
+
 def get_values(dag, funcs):
     defaults = dict()
     for name in dag.sig.names:
@@ -217,6 +234,12 @@ def get_funcs(dag):
     return funcs
 
 
+def get_from_configs(configs):
+    arg_types = configs['arg_types']
+    ranges = None if 'ranges' not in configs else configs['ranges']
+    return arg_types, ranges
+
+
 def get_default_configs(dags):
     configs = []
     for dag in dags:
